summary refs log tree commit diff
path: root/gnu/packages/base.scm
diff options
context:
space:
mode:
authorLudovic Courtès <ludo@gnu.org>2016-04-06 22:20:49 +0200
committerLudovic Courtès <ludo@gnu.org>2016-04-06 22:24:13 +0200
commite37595d9617658e3098b1d1b3f9f5d9aad4daf53 (patch)
treefa1b033206bf5465779aeadec07a13e85cd5fccd /gnu/packages/base.scm
parent61516a1613efd0e12afc83922b005e5218b3624a (diff)
downloadguix-e37595d9617658e3098b1d1b3f9f5d9aad4daf53.tar.gz
gnu: glibc: Update to 2.23.
* gnu/packages/base.scm (glibc): Update to 2.23.  Remove
"glibc-locale-incompatibility.patch" and "glibc-CVE-2015-7547.patch",
now unneeded.
[arguments]: Add "libc_cv_ssp_strong=no" to #:configure-flags.  Remove
now unneeded patching of 'configure'.
* gnu/packages/patches/glibc-CVE-2015-7547.patch: Remove.
* gnu/packages/patches/glibc-locale-incompatibility.patch: Remove.
* gnu-system.am (dist_patch_DATA): Adjust accordingly.
Diffstat (limited to 'gnu/packages/base.scm')
-rw-r--r--gnu/packages/base.scm16
1 files changed, 5 insertions, 11 deletions
diff --git a/gnu/packages/base.scm b/gnu/packages/base.scm
index 2010bc0d57..7a8844795b 100644
--- a/gnu/packages/base.scm
+++ b/gnu/packages/base.scm
@@ -459,14 +459,14 @@ store.")
 (define-public glibc
   (package
    (name "glibc")
-   (version "2.22")
+   (version "2.23")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnu/glibc/glibc-"
                                 version ".tar.xz"))
             (sha256
              (base32
-              "0j49682pm2nh4qbdw35bas82p1pgfnz4d2l7iwfyzvrvj0318wzb"))
+              "1s8krs3y2n6pzav7ic59dz41alqalphv7vww4138ag30wh0fpvwl"))
             (snippet
              ;; Disable 'ldconfig' and /etc/ld.so.cache.  The latter is
              ;; required on LFS distros to avoid loading the distro's libc.so
@@ -477,10 +477,8 @@ store.")
             (modules '((guix build utils)))
             (patches (map search-patch
                           '("glibc-ldd-x86_64.patch"
-                            "glibc-locale-incompatibility.patch"
                             "glibc-versioned-locpath.patch"
-                            "glibc-o-largefile.patch"
-                            "glibc-CVE-2015-7547.patch")))))
+                            "glibc-o-largefile.patch")))))
    (build-system gnu-build-system)
 
    ;; Glibc's <limits.h> refers to <linux/limit.h>, for instance, so glibc
@@ -497,7 +495,7 @@ store.")
       #:parallel-build? #f
 
       ;; The libraries have an empty RUNPATH, but some, such as the versioned
       ;; libraries (libdl-2.22.so, etc.) have ld.so marked as NEEDED.  Since
       ;; these libraries are always going to be found anyway, just skip
       ;; RUNPATH checks.
       #:validate-runpath? #f
@@ -539,7 +537,7 @@ store.")
                            "/bin/bash")
 
             ;; XXX: Work around "undefined reference to `__stack_chk_guard'".
-            "libc_cv_ssp=no")
+            "libc_cv_ssp=no" "libc_cv_ssp_strong=no")
 
       #:tests? #f                                 ; XXX
       #:phases (modify-phases %standard-phases
@@ -553,10 +551,6 @@ store.")
                            ;; but cross-base uses it as a native input.
                            (bash (or (assoc-ref inputs "static-bash")
                                      (assoc-ref native-inputs "static-bash"))))
-                      ;; Use `pwd', not `/bin/pwd'.
-                      (substitute* "configure"
-                        (("/bin/pwd") "pwd"))
-
                       ;; Install the rpc data base file under `$out/etc/rpc'.
                       ;; FIXME: Use installFlags = [ "sysconfdir=$(out)/etc" ];
                       (substitute* "sunrpc/Makefile"
@@ -497,7 +495,7 @@ store.")
 
       ;; The libraries have an empty RUNPATH, but some, such as the versioned
-      ;; libraries (libdl-2.22.so, etc.) have ld.so marked as NEEDED.  Since
+      ;; libraries (libdl-2.23.so, etc.) have ld.so marked as NEEDED.  Since
       ;; these libraries are always going to be found anyway, just skip
       ;; RUNPATH checks.